@@ -211,6 +211,10 @@ fit_tree_model = function(	tree,
 																				resolution					= params$resolution,
 																				rarefaction					= params$rarefaction,
 																				Nsplits 					= 2,
+																				additional_rates_times		= numeric(),
+																				additional_birth_rates_pc	= numeric(),
+																				additional_death_rates_pc	= numeric(),
+																				additional_periodic			= FALSE,
 																				times 						= events$speciation_times,
 																				start_time					= events$speciation_times[1],
 																				final_time					= events$max_distance_from_root,
@@ -258,6 +262,10 @@ fit_tree_model = function(	tree,
 																	resolution					= params$resolution,
 																	rarefaction					= params$rarefaction,
 																	Nsplits 					= 2,
+																	additional_rates_times		= numeric(),
+																	additional_birth_rates_pc	= numeric(),
+																	additional_death_rates_pc	= numeric(),
+																	additional_periodic			= FALSE,
 																	times 						= grid_times,
 																	start_time					= grid_times[1],
 																	final_time					= events$max_distance_from_root,
@@ -377,6 +385,10 @@ fit_tree_model = function(	tree,
 																resolution					= parameters$resolution,
 																rarefaction					= parameters$rarefaction,
 																Nsplits 					= 2,
+																additional_rates_times		= numeric(),
+																additional_birth_rates_pc	= numeric(),
+																additional_death_rates_pc	= numeric(),
+																additional_periodic			= FALSE,
 																times 						= grid_times,
 																start_time					= grid_times[1],
 																final_time					= events$max_distance_from_root,
